<?php
/**
 * Custom badges template
 *
 * @package BuddyPress_User_Badges
 */

// No direct access.
use BuddyDev\BuddyPress_User_Badges\Models\Badge;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>
<?php
$badges = Badge::get( array(
	'source'   => 'custom',
	'orderby'  => 'position',
	'order'    => 'ASC',
	'per_page' => 0,
) );
?>
<div class="bp-user-badges-section">

    <h1 class="bp-user-badges-title"><?php esc_html_e( 'Custom Badges', 'buddypress-user-badges' ); ?></h1>
    
    <form method="post" id="bp-user-badges-form" class="bp-user-badges-form deactive">
		<?php wp_nonce_field( 'bp-user-badges-save-badges' ); ?>
		<?php if ( $badges ) : ?>
            <div class="bp-user-badges-custom-badge-section">
			<?php foreach ( $badges as $badge ) : ?>
				<?php $active_class = $badge->is_active ? 'bp-user-badge-active' : 'bp-user-badge-inactive'; ?>

                <div class="bp-user-badges-custom-badge-wrap <?php echo $active_class;?> ">
                <h4 class="bp-user-badges-custom-badge" data-badge-id="<?php echo esc_attr( $badge->id ); ?>">
                    <?php echo $badge->name; ?>
                    <a href="<?php echo wp_nonce_url( admin_url( "admin.php?page=badges&badge_id={$badge->id}&bp_user_badges_action=delete-badge" ), 'bp-user-badges-delete-badge' ); ?>"
                       class="dashicons dashicons-no bp-user-badges-delete-badge-btn"></a>
                </h4>

                <fieldset id="bp-user-badges-custom-<?php echo $badge->id; ?>" class="bp-user-badges-form-fieldset deactive">
                    <input type="hidden" name="badge_id[]" value="<?php echo $badge->id;?>" />
                    <input type="hidden" name="bp_user_badges_badge_id[]" value="<?php echo esc_attr( $badge->id ); ?>"/>
                    <div class="bp-user-badges-form-field-row bp-user-badges-is-active">
                        <label>
                            <input type="checkbox" class="bp-user-badges-is-active" <?php checked( $badge->is_active, 1 ); ?>/>
                            <input type="hidden" name="bp_user_badges_is_active[]" class="bp-user-badges-is-active-text-field" value="<?php echo esc_attr( $badge->is_active ); ?>">
		                    <?php esc_html_e( 'Is active', 'buddypress-user-badges' ); ?>
                        </label>
                    </div>

                    <div class="bp-user-badges-form-field-row bp-user-badges-name">
                        <label><?php esc_html_e( 'Name', 'buddypress-user-badges' ); ?></label>
                        <input type="text" name="bp_user_badges_name[]" value="<?php echo esc_attr( $badge->name ); ?>"
                               placeholder="<?php esc_attr_e( 'Enter badge name', 'buddypress-user-badges' ); ?>">
                    </div>

                    <div class="bp-user-badges-form-field-row bp-user-badges-slug">
                        <label><?php esc_html_e( 'Slug', 'buddypress-user-badges' ); ?></label>
                        <input type="text" name="bp_user_badges_slug[]"
                               value="<?php echo esc_attr( $badge->slug ); ?>"/>
                        <p><?php esc_html_e( 'please enter badge unique slug here', 'buddypress-user-badges' ); ?></p>
                    </div>

                    <div class="bp-user-badges-form-field-row bp-user-badges-description">
                        <label><?php esc_html_e( 'Description', 'buddypress-user-badges' ); ?></label>
                        <textarea type="text"
                                  name="bp_user_badges_description[]"><?php echo esc_textarea( $badge->description ); ?></textarea>
                        <p><?php esc_html_e( 'Badge description to eleborate why this badge is used for', 'buddypress-user-badges' ); ?></p>
                    </div>

                    <div class="bp-user-badges-form-field-row bp-user-badges-link">
                        <label><?php esc_html_e( 'Link', 'buddypress-user-badges' ); ?></label>
                        <input type="text" name="bp_user_badges_link[]" value="<?php echo esc_attr( $badge->link ); ?>"
                               placeholder="<?php esc_attr_e( 'Attached link with this badge', 'buddypress-user-badges' ); ?>">
                        <p><?php esc_html_e( 'Link associated with this badge', 'buddypress-user-badges' ); ?></p>
                    </div>

                    <div class="bp-user-badges-form-field-row bp-user-badges-image-section">
                        <label> <?php esc_html_e( 'Image', 'buddypress-user-badges' ); ?></label>
                        <input name="bp_user_badges_image[]" class="bp-user-badges-image" type="hidden"
                               value="<?php echo esc_url( $badge->image ); ?>" size="40" aria-required="true">
                        <img src="<?php echo esc_url( $badge->image ); ?>" class="bp-user-badges-image-show"><br>
                        <a href="#"
                           class="button bp-user-badges-delete-image-btn"><?php esc_html_e( 'Remove', 'buddypress-user-badges' ); ?></a>
                        <a href="#" class="button bp-user-badges-upload-image-btn"
                           data-btn-title="<?php esc_attr_e( 'Upload image', 'buddypress-user-badges' ); ?>"
                           data-uploader-title="<?php esc_attr_e( 'Upload badge image', 'buddypress-user-badges' ); ?>"><?php esc_html_e( 'Upload image', 'buddypress-user-badges' ); ?></a>
                    </div>

                    <br>
                </fieldset>
                </div>
			<?php endforeach; ?>
            </div>
            <a href="#" class="button button-primary bp-user-badges-button"
               id="bp-user-badges-add-new-btn"><?php esc_html_e( 'Add New Badge', 'buddypress-user-badges' ); ?></a>
		<?php else : ?>
            <fieldset class="bp-user-badges-form-fieldset bp-user-badges-form-repeatable-fields">

                <div class="bp-user-badges-form-field-row bp-user-badges-is-active">
                    <label>
                        <input type="checkbox" class="bp-user-badges-is-active" />
                        <input type="hidden" name="bp_user_badges_is_active[]" class="bp-user-badges-is-active-text-field" value="">
		                <?php esc_html_e( 'Is active', 'buddypress-user-badges' ); ?>
                    </label>
                </div>

                <div class="bp-user-badges-form-field-row bp-user-badges-name">
                    <label><?php esc_html_e( 'Name', 'buddypress-user-badges' ); ?></label>
                    <input type="text" name="bp_user_badges_name[]" value=""
                           placeholder="<?php esc_attr_e( 'Enter badge name', 'buddypress-user-badges' ); ?>">
                </div>

                <div class="bp-user-badges-form-field-row bp-user-badges-slug">
                    <label><?php esc_html_e( 'Slug', 'buddypress-user-badges' ); ?></label>
                    <input type="text" name="bp_user_badges_slug[]" value=""/>
                    <p><?php esc_html_e( 'please enter badge unique slug here', 'buddypress-user-badges' ); ?></p>
                </div>

                <div class="bp-user-badges-form-field-row bp-user-badges-description">
                    <label><?php esc_html_e( 'Description', 'buddypress-user-badges' ); ?></label>
                    <textarea type="text" name="bp_user_badges_description[]"></textarea>
                    <p><?php esc_html_e( 'Badge description to eleborate why this badge is used for', 'buddypress-user-badges' ); ?></p>
                </div>

                <div class="bp-user-badges-form-field-row bp-user-badges-link">
                    <label><?php esc_html_e( 'Link', 'buddypress-user-badges' ); ?></label>
                    <input type="text" name="bp_user_badges_link[]" value="">
                    <p><?php esc_html_e( 'link associated with this badge', 'buddypress-user-badges' ); ?></p>
                </div>

                <div class="bp-user-badges-form-field-row bp-user-badges-image-section">
                    <label> <?php esc_html_e( 'Image', 'buddypress-user-badges' ); ?></label>
                    <input name="bp_user_badges_image[]" class="bp-user-badges-image" type="hidden" value="" size="40"
                           aria-required="true">
                    <img src="" class="bp-user-badges-image-show" style="display: none">
                    <a href="#" class="button bp-user-badges-delete-image-btn"
                       style="display: none;"><?php esc_html_e( 'Remove', 'buddypress-user-badges' ); ?></a>
                    <a href="#" class="button bp-user-badges-upload-image-btn"
                       data-btn-title="<?php esc_html_e( 'Upload image', 'buddypress-user-badges' ); ?>"
                       data-uploader-title="<?php esc_attr_e( 'Upload badge image', 'buddypress-user-badges' ); ?>"><?php esc_html_e( 'Upload image', 'buddypress-user-badges' ); ?></a>
                </div>

            </fieldset>
		<?php endif; ?>
        <input type="submit" class="button button-primary bp-user-badges-button bp-user-badges-save-details-btn"
               name="bp_user_badges_save_btn" value="<?php esc_attr_e( 'Save details', 'buddypress-user-badges' ); ?>">
    </form>

</div>
