<?php
/**
 * Badges associated with roles.
 *
 * @package BuddyPress_User_Badges
 */

// No direct access.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use BuddyDev\BuddyPress_User_Badges\Models\Badge;

$member_types = bp_get_member_types( false, 'objects' );
?>
<div class="bp-user-badges-section">
    <h1 class="bp-user-badges-title"><?php esc_html_e( 'Member type Badges', 'buddypress-user-badges' ); ?></h1>
    
	<?php if ( ! empty( $member_types ) ) : ?>
    <form method="post" id="bp-user-badges-member-type-badges-form" class="bp-user-badges-form deactive">
		<?php wp_nonce_field( 'bp-user-badges-save-member-type-badges' ); ?>
		<?php foreach ( $member_types as $member_type => $member_type_obj ) : ?>
			<?php
			$badge = bp_user_badges_get_badge_by_slug( $member_type, 'member_type' );
			$badge = empty( $badge ) ? Badge::create( array() ) : $badge;
			?>
	    <?php $active_class = $badge->is_active ? 'bp-user-badge-active' : 'bp-user-badge-inactive'; ?>

        <div class="bp-user-badges-member-type-badge-wrap <?php echo $active_class;?> ">
            <h4 class="bp-user-badges-member-type-badge" data-member-type="<?php echo esc_attr( $member_type ); ?>"><?php echo esc_html( $member_type_obj->labels['name'] ); ?></h4>

            <fieldset id="bp-user-badges-member-type-<?php echo $member_type; ?>" class="bp-user-badges-form-fieldset deactive">

                <input type="hidden" name="bp_user_badges_badge_id[]" value="<?php echo esc_attr( $badge->id ); ?>"/>
                <input type="hidden" name="bp_user_badges_name[]" value="<?php echo esc_attr( $member_type_obj->labels['name'] ); ?>"/>

                <input type="hidden" name="bp_user_badges_slug[]" value="<?php echo esc_attr( $member_type ); ?>"/>

                <div class="bp-user-badges-form-field-row bp-user-badges-is-active">
                    <label>
                        <input type="checkbox" class="bp-user-badges-is-active" <?php checked( $badge->is_active, 1 ); ?>/>
                        <input type="hidden" name="bp_user_badges_is_active[]" class="bp-user-badges-is-active-text-field" value="<?php echo esc_attr( $badge->is_active ); ?>">
						<?php esc_html_e( 'Is active', 'buddypress-user-badges' ); ?>
                    </label>
                </div>

                <div class="bp-user-badges-form-field-row bp-user-badges-description">
                    <label><?php esc_html_e( 'Description', 'buddypress-user-badges' ); ?></label>
                    <textarea type="text" name="bp_user_badges_description[]"><?php echo esc_textarea( $badge->description ); ?></textarea>
                    <p><?php esc_html_e( 'Badge description to eleborate why this badge is used for', 'buddypress-user-badges' ); ?></p>
                </div>

                <div class="bp-user-badges-form-field-row bp-user-badges-link">
                    <label><?php esc_html_e( 'Link', 'buddypress-user-badges' ); ?></label>
                    <input type="text" name="bp_user_badges_link[]" value="<?php echo esc_attr( $badge->link ); ?>" placeholder="<?php esc_attr_e( 'Attached link with this badge', 'buddypress-user-badges' ); ?>">
                    <p><?php esc_html_e( 'Link associated with this badge', 'buddypress-user-badges' ); ?></p>
                </div>

                <div class="bp-user-badges-form-field-row bp-user-badges-image-section">
                    <label> <?php esc_html_e( 'Image', 'buddypress-user-badges' ); ?></label>
                    <input name="bp_user_badges_image[]" class="bp-user-badges-image" type="hidden" value="<?php echo esc_url( $badge->image ); ?>" size="40" aria-required="true">
                    <img src="<?php echo esc_url( $badge->image ); ?>" class="bp-user-badges-image-show">
                    <a href="#" class="button bp-user-badges-delete-image-btn deactive"><?php esc_html_e( 'Remove', 'buddypress-user-badges' ); ?></a>
                    <a href="#" class="button bp-user-badges-upload-image-btn" data-btn-title="<?php esc_attr_e( 'Upload image', 'buddypress-user-badges' ); ?>" data-uploader-title="<?php esc_attr_e( 'Upload badge image', 'buddypress-user-badges' ); ?>"><?php esc_html_e( 'Upload image', 'buddypress-user-badges' ); ?></a>
                </div>

            </fieldset>
        </div>
			<?php endforeach; ?>

        <input type="submit" class="button button-primary bp-user-badges-button bp-user-badges-member-type-badges-save-details-btn" name="bp_user_badges_member_type_badges_save_btn" value="<?php esc_attr_e( 'Save member types details', 'buddypress-user-badges' ); ?>">
    </form>
    <?php else : ?>
    <p><?php esc_html_e( 'No member type found', 'buddypress-user-badges' ); ?></p>
    <?php endif; ?>
</div>
