<?php
/**
 * Assets Loader
 *
 * @package    buddypress-user-badges
 * @subpackage Bootstrap
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh, Ravi Sharma
 * @since      1.0.0
 */

namespace BuddyDev\BuddyPress_User_Badges\Bootstrap;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 0 );
}

/**
 * Assets Loader.
 */
class Assets_Loader {

	/**
	 * Data to be send as localized js.
	 *
	 * @var array
	 */
	private $data = array();

	/**
	 * Boot itself
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup
	 */
	public function setup() {
		add_action( 'admin_enqueue_scripts', array( $this, 'load_admin_assets' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'load_assets' ) );
	}

	/**
	 * Load plugin assets
	 */
	public function load_admin_assets() {
		$this->register();
	}

	/**
	 * Load plugin assets
	 */
	public function load_assets() {
		$bp_user_badges = bp_user_badges();

		wp_register_style( 'bp_user_badges_css', $bp_user_badges->url . 'assets/css/buddypress-user-badges.css', array(), $bp_user_badges->version );
		wp_enqueue_style( 'bp_user_badges_css' );
	}

	/**
	 * Register assets.
	 */
	public function register() {
		$this->register_core();
	}

	/**
	 * Load assets.
	 */
	public function enqueue() {}

	/**
	 * Register core assets.
	 */
	private function register_core() {
		$bp_user_badges = bp_user_badges();
		$url            = $bp_user_badges->url;
		$version        = $bp_user_badges->version;

		wp_register_style( 'bp_user_badges_admin_css', $url . 'src/admin/assets/css/buddypress-user-badges-admin.css', false, $version );
		wp_register_script( 'bp_user_badges_admin_js', $url . 'src/admin/assets/js/buddypress-user-badges-admin.js', array( 'jquery', 'jquery-ui-sortable', 'jquery-ui-accordion' ), $version );

		$this->data = array();
	}
}
