<?php
/**
 * Bootstrapper. Initializes the plugin.
 *
 * @package    buddypress-user-badges
 * @subpackage Bootstrap
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 * @since      1.0.0
 */

namespace BuddyDev\BuddyPress_User_Badges\Bootstrap;

use BuddyDev\BuddyPress_User_Badges\Admin\Admin_Helper;
use BuddyDev\BuddyPress_User_Badges\Admin\Admin_Settings_Helper;
use BuddyDev\BuddyPress_User_Badges\Handlers\BB_Display_Helper;
use BuddyDev\BuddyPress_User_Badges\Handlers\BBP_Display_Helper;
use BuddyDev\BuddyPress_User_Badges\Handlers\BP_Display_Helper;
use BuddyDev\BuddyPress_User_Badges\Handlers\Hooks_Helper;
use BuddyDev\BuddyPress_User_Badges\Handlers\Actions_Handler;
use BuddyDev\BuddyPress_User_Badges\Handlers\Shortcode_Helper;

// No direct access.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 0 );
}

/**
 * Bootstrapper.
 */
class Bootstrapper {

	/**
	 * Setup the bootstrapper.
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Bind hooks
	 */
	private function setup() {
		add_action( 'bp_loaded', array( $this, 'load' ), 1 );
		add_action( 'plugins_loaded', array( $this, 'load_admin' ), 9996 ); // pt settings 1.0.4.
		add_action( 'bp_init', array( $this, 'load_translations' ) );
	}

	/**
	 * Load core functions/template tags.
	 * These are non auto loadable constructs.
	 */
	public function load() {
		$path = bp_user_badges()->path;

		$files = array(
			'src/core/bp-user-badges-functions.php',
		);

		foreach ( $files as $file ) {
			require_once $path . $file;
		}

		Hooks_Helper::boot();

		if ( defined( 'BP_PLATFORM_VERSION' ) ) {
			BB_Display_Helper::boot();
		} else {
			BP_Display_Helper::boot();
		}

		if ( function_exists( 'bbpress' ) ) {
			BBP_Display_Helper::boot();
		}

		Actions_Handler::boot();
		Shortcode_Helper::boot();
		Assets_Loader::boot();
	}

	/**
	 * Load pt-settings framework
	 */
	public function load_admin() {

		if ( function_exists( 'buddypress' ) && is_admin() && ! wp_doing_ajax() ) {
			require_once bp_user_badges()->path . 'src/admin/pt-settings/pt-settings-loader.php';
			Admin_Helper::boot();
			Admin_Settings_Helper::boot();
		}
	}

	/**
	 * Load translations.
	 */
	public function load_translations() {
		load_plugin_textdomain( 'buddypress-user-badges', false, basename( dirname( bp_user_badges()->path ) ) . '/languages' );
	}
}
