<?php
/**
 * Hooks helper class
 *
 * @package buddpress-user-badges
 * @subpackage Handlers
 */

namespace BuddyDev\BuddyPress_User_Badges\Handlers;

use BuddyDev\BuddyPress_User_Badges\Models\Badge;

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Base class for helping with display.
 */
class Badge_Display_Helper {

	/**
	 * Setup.
	 */
	protected function setup() {
		add_filter( 'bp_user_badges_user_badges', array( $this, 'modify_badges' ), 10, 2 );
	}


	/**
	 * Get user badges
	 *
	 * @param int $user_id User id.
	 *
	 * @return string
	 */
	public function get_user_badges_html( $user_id ) {
		return bp_user_badges_get_user_badges_html( $user_id );
	}

	/**
	 * Modify badges
	 *
	 * @param Badge[] $badges Badges.
	 * @param int     $user_id User id.
	 *
	 * @return Badge[]
	 */
	public function modify_badges( $badges, $user_id ) {

		$enabled_badge_types = (array) bp_user_badges_get_option( 'enabled_badge_types' );

		if ( in_array( 'role', $enabled_badge_types, true ) ) {
			$badges = $this->attach_role_badges( $badges, $user_id );
		}

		if ( in_array( 'member_type', $enabled_badge_types, true ) ) {
			$badges = $this->attach_member_type_badges( $badges, $user_id );
		}

		return $badges;
	}

	/**
	 * Modify badges
	 *
	 * @param Badge[] $badges Badges.
	 * @param int     $user_id User id.
	 *
	 * @return Badge[]
	 */
	private function attach_role_badges( $badges, $user_id ) {

		$user = get_user_by( 'id', $user_id );

		$role_badges = array();
		foreach ( (array) $user->roles as $role ) {
			$role_badge = bp_user_badges_get_badge_by_slug( $role, 'role' );

			if ( empty( $role_badge ) || ! $role_badge->is_active ) {
				continue;
			}

			$role_badges[] = $role_badge;
		}

		if ( 'after_custom' === bp_user_badges_get_option( 'role_badges_position' ) ) {
			$badges = array_merge( $badges, $role_badges );
		} else {
			$badges = array_merge( $role_badges, $badges );
		}

		return $badges;
	}

	/**
	 * Modify badges
	 *
	 * @param Badge[] $badges Badges.
	 * @param int     $user_id User id.
	 *
	 * @return Badge[]
	 */
	private function attach_member_type_badges( $badges, $user_id ) {

		$member_types = bp_get_member_type( $user_id, false );

		if ( empty( $member_types ) ) {
			return $badges;
		}

		$role_badges = array();
		foreach ( $member_types as $member_type ) {
			$role_badge = bp_user_badges_get_badge_by_slug( $member_type, 'member_type' );

			if ( empty( $role_badge ) || ! $role_badge->is_active ) {
				continue;
			}

			$role_badges[] = $role_badge;
		}

		if ( 'after_custom' === bp_user_badges_get_option( 'member_type_badges_position' ) ) {
			$badges = array_merge( $badges, $role_badges );
		} else {
			$badges = array_merge( $role_badges, $badges );
		}

		return $badges;
	}

}
