<?php
/**
 * BuddyBoss badge display helper
 *
 * @package buddpress-user-badges
 * @subpackage Handlers
 */

namespace BuddyDev\BuddyPress_User_Badges\Handlers;

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Helper for displaying badges with BuddyBoss theme.
 */
class BB_Display_Helper extends Badge_Display_Helper {

	/**
	 * Boot itself
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup hooks
	 */
	protected function setup() {
		parent::setup();

		// User profile header badge.
		add_action( 'bp_profile_header_meta', array( $this, 'add_member_profile_badges' ) );
		add_action( 'bp_before_member_header_meta', array( $this, 'add_member_profile_badges' ) );


		// bb dir, used when member type on profile is not enabled.
		add_action( 'bp_directory_members_item', array( $this, 'add_members_list_badges' ), 0 );
		// bb dir:- used when member type on profile is enabled.
		add_action(
			'bp_member_members_list_item',
			array( $this, 'add_members_list_badges_when_profile_type_enabled' ),
			0
		);

		//add_action( 'bp_group_members_list_item', array( $this, 'add_group_members_list_badges' ) );

		// bb group dir.
		//add_filter( 'bp_get_group_member_joined_since', array( $this, 'append_group_members_list_badges' ) );

	}

	/**
	 * Show users badge in members directory
	 *
	 * Works only when profile type is not enabled to show on profile.
	 */
	public function add_members_list_badges() {

		$show_badges_in = (array) bp_user_badges_get_option( 'badge_display_context' );


		if ( bp_is_members_directory() &&  in_array( 'members_directory', $show_badges_in, true ) ) {
			echo $this->get_user_badges_html( bp_get_member_user_id() );
		}
	}

	/**
	 * Add user badges to members directory when profile type is enabled to be shown on profile.
	 */
	public function add_members_list_badges_when_profile_type_enabled() {

		$show = false;

		$show_badges_in = (array) bp_user_badges_get_option( 'badge_display_context' );

		if ( in_array( 'members_directory', $show_badges_in, true ) && bp_is_members_directory() ) {
			$show = true;
		} elseif ( in_array( 'group_members_list', $show_badges_in, true ) && function_exists( 'bp_is_group_members' ) && bp_is_group_members() ) {
			$show = true;
		}

		if ( $show ) {
			echo $this->get_user_badges_html( bp_get_member_user_id() );
		}
	}

	/**
	 * Show group members list badges.
	 *
	 * Used when profile type are disabled or not enabled to be shown on profile.
	 *
	 * @param  string $meta meta.
	 *
	 * @return string
	 */
	private function append_group_members_list_badges( $meta ) {

		//return $meta;
		if ( $this->is_bb_members_dir_meta_hidden() ) {
			return $meta;
		}

		$show_badges_in = (array) bp_user_badges_get_option( 'badge_display_context' );

		if ( in_array( 'group_members_list', $show_badges_in, true ) ) {
			return $meta . $this->get_user_badges_html( bp_get_member_user_id() );
		}

		return $meta;
	}

	/**
	 * Show badge on user profile page
	 */
	public function add_member_profile_badges() {
		// BuddyBoss 1.9.0+ has a bug that calls the bp_before_member_header_meta twice.
		static $called = null;
		if ( $called ) {
			return;
		}

		$called = true;

		$show_badges_in = (array) bp_user_badges_get_option( 'badge_display_context' );

		$badges = '';
		if ( in_array( 'user_profile', $show_badges_in, true ) ) {
			$badges = $this->get_user_badges_html( bp_displayed_user_id() );
		}

		echo $badges;
	}

	/**
	 * Is BuddyBoss directory meta hidden.
	 *
	 * @return bool
	 */
	private function is_bb_members_dir_meta_hidden() {
		static $is_hidden = null;
		if ( is_null( $is_hidden ) ) {
			$is_hidden = true === bp_member_type_enable_disable() && true === bp_member_type_display_on_profile();
		}

		return $is_hidden;
	}
}
