<?php
/**
 * Hooks helper class
 *
 * @package buddpress-user-badges
 * @subpackage Handlers
 */

namespace BuddyDev\BuddyPress_User_Badges\Handlers;

// Exit if file accessed directly.
use BuddyDev\BuddyPress_User_Badges\Models\Badge;
use BuddyDev\BuddyPress_User_Badges\Models\Badge_Relationship;

// No direct access.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 0 );
}

/**
 * Class Hooks_Helper
 */
class BP_Display_Helper extends  Badge_Display_Helper{

	/**
	 * Boot itself
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup hooks
	 */
	protected function setup() {
		parent::setup();

		// user header.
		add_action( 'bp_profile_header_meta', array( $this, 'add_member_profile_badges' ) );
		add_filter( 'yz_user_profile_username', array( $this, 'add_yz_member_profile_badges' ) );
		// for community builder.
		add_action( 'bp_member_header_meta', array( $this, 'add_member_profile_badges' ) );
		// dir.
		add_action( 'bp_directory_members_item', array( $this, 'add_members_list_badges_nouveau' ), 0 );
		add_action( 'bp_directory_members_item', array( $this, 'add_members_list_badges' ), 0 );
		add_action( 'bp_group_members_list_item', array( $this, 'add_group_members_list_badges' ) );

	}
	/**
	 * Show users badge in members directory
	 *
	 * Works only when profile type is not enabled to show on profile.
	 */
	public function add_members_list_badges() {

		if ( function_exists( 'bp_nouveau' ) ) {
			return;
		}

		$show_badges_in = (array) bp_user_badges_get_option( 'badge_display_context' );

		if ( in_array( 'members_directory', $show_badges_in, true ) ) {
			echo $this->get_user_badges_html( bp_get_member_user_id() );
		}
	}

	/**
	 * Added youzer user badges
	 *
	 * @param string $user_name User name.
	 *
	 * @return string
	 */
	public function add_yz_member_profile_badges( $user_name ) {

		ob_start();

		$this->add_member_profile_badges();

		$badges = ob_get_clean();

		$user_name .= $badges;

		return $user_name;
	}

	/**
	 * Add user badges
	 */
	public function add_members_list_badges_nouveau() {

		if ( ! function_exists( 'bp_nouveau' ) ) {
			return;
		}

		$show_badges_in = (array) bp_user_badges_get_option( 'badge_display_context' );

		if ( in_array( 'members_directory', $show_badges_in, true ) ) {
			echo $this->get_user_badges_html( bp_get_member_user_id() );
		}
	}

	/**
	 * Show group members list badges.
	 */
	public function add_group_members_list_badges() {

		$show_badges_in = (array) bp_user_badges_get_option( 'badge_display_context' );

		if ( in_array( 'group_members_list', $show_badges_in, true ) ) {
			echo $this->get_user_badges_html( bp_get_member_user_id() );
		}

	}

	/**
	 * Show profile badges
	 */
	public function add_member_profile_badges() {

		$show_badges_in = (array) bp_user_badges_get_option( 'badge_display_context' );

		$badges = '';
		if ( in_array( 'user_profile', $show_badges_in, true ) ) {
			$badges = $this->get_user_badges_html( bp_displayed_user_id() );
		}

		echo $badges;
	}

}
