<?php
/**
 * Hooks helper class
 *
 * @package buddpress-user-badges
 * @subpackage Handlers
 */

namespace BuddyDev\BuddyPress_User_Badges\Handlers;

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Class Hooks_Helper
 */
class Hooks_Helper {

	/**
	 * Boot itself
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup hooks
	 */
	private function setup() {

		add_filter( 'bp_after_has_members_parse_args', array( $this, 'filter_members_list' ) );

		add_filter( 'upload_mimes', array( $this, 'filter_mime_types' ) );
		add_action( 'wp_head', array( $this, 'add_css' ) );

		$badges_visibility = (array) bp_user_badges_get_option( 'badge_display_context' );

		if ( $this->is_classes_enabled() && in_array( 'members_directory', $badges_visibility, true ) ) {
			add_filter( 'bp_get_member_class', array( $this, 'add_badges_class' ) );
		}
	}

	/**
	 * Filter members list
	 *
	 * @param array $args {
	 *      for parameters @see bp_has_members().
	 * }
	 *
	 * @return array
	 */
	public function filter_members_list( $args ) {

		if ( ! empty( $args['badges'] ) ) {
			$badges = wp_parse_id_list( $args['badges'] );

			$relationships = bp_user_badges_get_relationships(
				array(
					'badge_id' => array(
						'op'    => 'IN',
						'value' => $badges,
					),
                    'per_page' => 0,
				)
			);

			if ( empty( $relationships ) ) {
				$args['include'] = array( 0 );
			}

			$user_ids        = wp_list_pluck( $relationships, 'user_id' );
			$args['include'] = $user_ids;
		}

		return $args;
	}


	/**
	 * Add css to members directory entry.
	 *
	 * @param array $classes classes.
	 *
	 * @return array
	 */
	public function add_badges_class( $classes ) {

		$user_id = bp_get_member_user_id();

		if ( bp_user_badges_get_user_badges( $user_id ) ) {
			$classes[] = 'has-bp-user-badge';
		}

		return $classes;
	}

	/**
	 * Filter mime type for uploading
	 *
	 * @param array $mimes Mimes array.
	 *
	 * @return array
	 */
	public function filter_mime_types( $mimes ) {

		if ( ! isset( $mimes['svg'] ) ) {
			$mimes['svg'] = 'image/svg+xml';
		}

		return $mimes;
	}

	/**
	 * Add css on directory.
	 */
	public function add_css() {
		if ( apply_filters( 'bp_user_badges_disable_css', bp_user_badges_get_option( 'disable_css' ) ) ) {
			return;
		}
		?>

        <style type="text/css">
            .bp-user-badges-badge-list img {
                width: 32px;
            }
        </style>
		<?php
	}

	/**
	 * BuddyBoss does not show the meta if profile type is enabled and show on profile is on.
	 *
	 * We only add class if that is not the case.
	 *
	 * @return bool
	 */
	private function is_classes_enabled() {
		$is = true;
		if ( defined( 'BP_PLATFORM_VERSION' ) && function_exists( 'bp_member_type_enable_disable' ) && function_exists( 'bp_member_type_display_on_profile' ) ) {
			$is = ( true === bp_member_type_enable_disable() && true === bp_member_type_display_on_profile() ) ? false : true;
		}

		return $is;
	}
}
