<?php
/**
 * Action handler class
 *
 * @package    BuddyPress_User_Badges
 * @subpackage Handlers
 */

namespace BuddyDev\BuddyPress_User_Badges\Handlers;

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Class Shortcode_Helper
 */
class Shortcode_Helper {

	/**
	 * Class self boot
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup
	 */
	private function setup() {
		add_shortcode( 'bp-user-badges', array( $this, 'render' ) );
	}

	/**
	 * Render shortcode content
	 *
	 * @param array $atts Shortcode atts.
	 *
	 * @return string
	 */
	public function render( $atts ) {
		$atts = shortcode_atts(
			array(
				'slug'            => '',
				'max'             => 5,
				'view'            => '', // 'default', 'list'.
				'context'         => '', // 'role', 'member_type'.
				'bb_theme_compat' => 1,
				'bb_view'         => function_exists( 'bb_theme_register_buddypanel_block' ) ? 'v2' : 'v1',
			),
			$atts,
			'bp-user-badges'
		);

		$view            = in_array( $atts['view'], array( 'default', 'list' ) ) ? $atts['view'] : 'default';
		$badge_slug      = $atts['slug'];
		$badge_cotext    = $atts['context'];
		$bb_theme_compat = $atts['bb_theme_compat'];

		$badge        = bp_user_badges_get_badge_by_slug( $badge_slug, $badge_cotext );
		// Return if badge info not found or badge not active.
		if ( ! $badge || ! $badge->is_active ) {
			return '';
		}

		if ( 'role' === $badge_cotext ) {
			$user_ids = get_users(
				array(
					'fields' => 'ID',
					'role'   => $badge_slug,
					'number' => $atts['max'],
				)
			);
		} elseif ( 'member_type' === $badge_cotext ) {
			$uq             = new \BP_User_Query();
			$uq->query_vars = array(
				'type'                => 'newest',
				'per_page'            => $atts['max'],
				'page'                => 1,
				'user_id'             => 0,
				'search_terms'        => false,
				'search_wildcard'     => 'both',
				'include'             => false,
				'exclude'             => false,
				'user_ids'            => false,
				'member_type'         => $badge_slug,
				'member_type__in'     => '',
				'member_type__not_in' => '',
				'meta_key'            => false,
				'meta_value'          => false,
				'xprofile_query'      => false,
				'populate_extras'     => false,
				'count_total'         => 'count_query',
			);
			$uq->prepare_user_ids_query();
			$uq->do_user_ids_query();
			$user_ids = $uq->user_ids;
		} else {
			// Max number to per_page.
			$relationships = bp_user_badges_get_relationships(
				array(
					'badge_id' => $badge->id,
					'per_page' => $atts['max'],
				)
			);

			$user_ids = $relationships ? wp_list_pluck( $relationships, 'user_id' ) : array( 0 );
		}

		if ( empty( $user_ids ) ) {
			$user_ids = array( 0, 0 );
		}

		$template_parts = "shortcodes/{$view}.php";

		if ( defined( 'BP_PLATFORM_VERSION' ) ) {
			$template_parts = 'v2' == $atts['bb_view'] ? 'shortcodes/buddyboss/default-v2.php' : 'shortcodes/buddyboss/default.php';
		}

		ob_start();

		$template = bp_user_badges_locate_template( $template_parts, false );

		if ( $template && is_readable( $template ) ) {
			require_once $template;
		}

		return ob_get_clean();
	}
}

