<?php
/**
 * Model class for Badges
 *
 * @package buddpress-user-badges
 * @subpackage Models
 */

namespace BuddyDev\BuddyPress_User_Badges\Models;

use BuddyDev\BuddyPress_User_Badges\Schema\Schema;

// No direct access.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Model Class For Badge
 *
 * @property-read int    $id          Badge id.
 * @property-read string $name        Name.
 * @property-read string $slug        Badge slug.
 * @property-read string $description Badge description.
 * @property-read string $image       Associate image with badge.
 * @property-read string $link        Associate link with badge.
 * @property-read int    $position    Badge position.
 * @property-read string $source      Badge position.
 * @property-read string $context     Badge position.
 * @property-read int    $is_active   Badge active.
 * @property-read string $created_at  Moderation date
 * @property-read string $updated_at  Moderation date
 */
class Badge extends Model {
	/**
	 * Badge id
	 *
	 * @var string
	 */
	public $id = '';

	/**
	 * Badge name
	 *
	 * @var string
	 */
	public $name = '';

	/**
	 * Badge slug
	 *
	 * @var string
	 */
	public $slug = '';

	/**
	 * Badge description
	 *
	 * @var string
	 */
	public $description = '';

	/**
	 * Associated image with badge
	 *
	 * @var string
	 */
	public $image = '';

	/**
	 * Associate link with the badge
	 *
	 * @var string
	 */
	public $link = '';

	/**
	 * Badge position
	 *
	 * @var string
	 */
	public $position = '';

	/**
	 * Badge source either predefined or custom
	 *
	 * @var string
	 */
	public $source = '';

	/**
	 * Badge source context. For ex. role, member-type etc
	 *
	 * @var string
	 */
	public $context = '';
    // [type = source+context].
	/**
	 * Is active
	 *
	 * @var int
	 */
	public $is_active = 0;

	/**
	 * Get the table name.
	 *
	 * @return string
	 */
	public static function table() {
		return Schema::table( 'badges' );
	}

	/**
	 * Get table schema.
	 *
	 * @return array
	 */
	public static function schema() {

		return array(
			'id'          => 'integer',
			'name'        => 'string',
			'slug'        => 'string',
			'description' => 'string',
			'image'       => 'string',
			'link'        => 'string',
			'position'    => 'integer',
			'source'      => 'string',
			'context'     => 'string',
			'is_active'   => 'integer',
			'created_at'  => 'datetime',
			'updated_at'  => 'datetime',
		);
	}
}
