<?php
/**
 * Database Schema helper
 *
 * @package    buddypress-user-badges
 * @subpackage Schema
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 * @since      1.0.0
 */

namespace BuddyDev\BuddyPress_User_Badges\Schema;

// No direct access.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Schema Manager.
 *
 * For actual models, Please see models directory.
 */
class Schema {

	/**
	 * Get table name.
	 *
	 * @param string $name table identifier.
	 *
	 * @return null|string full table name or null.
	 */
	public static function table( $name ) {
		$tables = array(
			'badges'              => 'badges',
			'badge_relationships' => 'badge_relationships',
		);

		global $wpdb;

		$prefix = $wpdb->prefix; // bp_user_badges()->is_network_active() ? $wpdb->base_prefix : $wpdb->prefix;

		return isset( $tables[ $name ] ) ? $prefix . $tables[ $name ] : null;
	}

	/**
	 * Create Tables.
	 */
	public static function create() {
		global $wpdb;

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$charset_collate           = $wpdb->get_charset_collate();
		$badges_table              = self::table( 'badges' );
		$badge_relationships_table = self::table( 'badge_relationships' );

		$sql = array();

		if ( ! self::exists( $badges_table ) ) {
			$sql[] = "CREATE TABLE `{$badges_table}`(
  				`id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
  				`name` varchar(92) NOT NULL,
  				`slug` varchar(92) NOT NULL,
  				`description` text NOT NULL DEFAULT '',
  				`image` varchar(255) NOT NULL DEFAULT '',
  				`link` varchar(255) NOT NULL DEFAULT '',
  				`position` smallint NOT NULL DEFAULT 0,
  				`source` varchar(20) NOT NULL,
  				`context` varchar(20) NOT NULL,
  				`is_active` smallint NOT NULL DEFAULT 1,
  				`created_at` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  				`updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP  				 
			){$charset_collate};";
		}

		if ( ! self::exists( $badge_relationships_table ) ) {
			$sql[] = "CREATE TABLE `{$badge_relationships_table}`(
  				`user_id` bigint(20) NOT NULL,
  				`badge_id` bigint(20) NOT NULL,
  				CONSTRAINT `{$badge_relationships_table}` UNIQUE (user_id,badge_id)  				 
			){$charset_collate};";
		}

		if ( ! $sql ) {
			return;
		}

		dbDelta( $sql );
	}

	/**
	 * Check if table exists.
	 *
	 * @param string $table_name table name.
	 *
	 * @return bool
	 */
	public static function exists( $table_name ) {
		global $wpdb;

		return $wpdb->get_var( $wpdb->prepare( "SHOW TABLES LIKE %s", $table_name ) ) === $table_name;
	}
}
